#!/bin/sh
#
# new_index.sh - simple indexer of waisindex
#
# written by Hajime BABA <baba@kusastro.kyoto-u.ac.jp>
# (C) Copyright 1997 Hajime BABA. All rights reserved.
# 

indexname="mail"

waisindex="/usr/local/bin/waisindex";
options="-japanese -l 5 -t fields";
list="list.`date '+%y%m%d'`"

mailfolder="`/usr/local/bin/mh/mhpath +`"


#
if [ ! -d ${HOME}/wais-sources ]; then
    echo -n "${HOME}/wais-sources/ does not exist.  Creating... "
    mkdir ${HOME}/wais-sources/
    echo "done."
fi
echo "Entering directory ${HOME}/wais-sources/"
cd ${HOME}/wais-sources/

#
if [ -f $indexname.syn ]; then
    echo "Mmm... $indexname.syn already exists.  Skipped."
else
    echo -n "Creating synonym file $indexname.syn... "
    cp /dev/null $indexname.syn
    echo "done."
fi

#
if [ -f $indexname.fmt ]; then
    echo "Mmm... $indexname.fmt already exists.  Skipped."
else
    echo -n "Creating format file $indexname.fmt... "
    cat > $indexname.fmt <<EOF
# mail.fmt -- format file for E-mail/NetNews articles
# written by Hajime BABA <baba@kusastro.kyoto-u.ac.jp>
# (C) Copyright 1997 Hajime BABA. All rights reserved.

# record separater
record-sep: /\n\n/    # never !

# layout section
layout:
# From: Hajime BABA <baba@kusastro.kyoto-u.ac.jp>
  headline: /^From: / /<.*>\n/ 21 /^From: [ ]*/
# Subject: hogehoge hogege...
  headline: /^Subject: / /\n/ 80 /^Subject:/
end:

# body section
region: //
  TEXT GLOBAL
end: /$/

## EOF
EOF
    echo "done."
fi

# 
echo "Creating file lists under the $mailfolder directory to \"$list\"."
echo -n "Just a moment please... "
find $mailfolder -type f -name "[1-9]*" -print > $list
echo "done."

# go!
echo "OK.  Now let's get started indexing using \"$list\" !"
cat $list | xargs $waisindex -a $options -d $indexname

# ending
echo ""
echo "new_index.sh completed."

## EOF
